<?php
/* Plugin Name:  WP SimplePost Contributors
 * Description:  Allow you to add more than one author of the post.
 * Version:      1.0
 * Author:       Ashish Odich
 * Contributors: ashishodich
 * Requires at least: 4.0
 *
 *
 * @package WP SimplePost Contributors
 * @category WP SimplePost Contributors
 * @author Ashish Odich
*/
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

//  Add Meta Box
add_action( 'add_meta_boxes', 'wpspc_add_meta_box' );
// Save meta box value
add_action( 'save_post', 'wpspc_save' );
// Display contributors
add_filter( 'the_content', 'wpspc_display');

function wpspc_add_meta_box() {
	add_meta_box('wpspc_meta_box','Contributors','wpspc_render_meta_box','post','side','core');
}

// Render Meta Box
function wpspc_render_meta_box( $post ) {
	wp_nonce_field( 'wpspc_inner_custom_box', 'wpspc_inner_custom_box_nonce' );
	$contributors = get_post_meta( $post->ID, '_wp_contributor', true );
	if( !empty($contributors) )
		$contributors = explode( ",", $contributors );
	else {
		$contributors = array();
	}
				
	$authors = get_users( 'orderby=nicename' );

	if( count( $authors ) > 0 ) {
		echo "<ul id='wp_contributor_list'>";
		foreach ( $authors as $author ) {
			if( in_array( $author->ID, $contributors ) )
				echo "<li> <input checked='checked' type='checkbox' name='wp_contributor[]' value='".$author->ID."' /> ". esc_html( $author->nickname) . "</li>";
			else
				echo "<li> <input type='checkbox' name='wp_contributor[]' value='".$author->ID."' /> ". esc_html( $author->nickname) . "</li>";
		}
		echo "</ul>";
	}
}

// Save values of meta box
function wpspc_save( $post_id ) {

	if ( !isset( $_POST['wpspc_inner_custom_box_nonce'] ) )
		return $post_id;

	$nonce = $_POST['wpspc_inner_custom_box_nonce'];
	
	if ( !wp_verify_nonce( $nonce, 'wpspc_inner_custom_box' ) )
		return $post_id;

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
		return $post_id;

	if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;

	$wp_contributor = sanitize_meta('_wp_contributor', $_POST['wp_contributor'], 'post' );
	
	if( isset( $wp_contributor ) && $wp_contributor != '' ) {
		update_post_meta( $post_id, '_wp_contributor', implode( ",", $wp_contributor) );
	}
	else {
		update_post_meta( $post_id, '_wp_contributor', '' );
	}
}

// Display Post Contributors
function wpspc_display( $content ) {
	
	global $post; $html = '';
	$html .= "<div class='wrapper-container'> <h4>Contributors</h4>";
	$contributors = get_post_meta( $post->ID, '_wp_contributor', true );
	
	if($contributors == '') return $content;
			
	$contributors = explode( ",", $contributors );
	
	$html .= "<ul class='mall-block-grid-6 contrib-list'> <div class = 'row'>";
	$html .= "<div class = 'small columns-12'>";

	foreach ( $contributors as $contributor ) {
		$contributor_info = get_userdata( $contributor );
		$html .= "<li class='img-wrapper'><a class = '' href='".get_author_posts_url( $contributor_info->ID )."'>". get_avatar( $contributor, 40 )."<p class = 'author-name'>".esc_html( $contributor_info->nickname ) . "</p> </a></li>";
	}
	
	$html .= "</div></div></ul>";
	$html .= "</div><div style='clear:both;'></div>";
	return $content.$html;
}
